/* acconfig.h: Descriptions of macros produced by autoconf
   Copyright (c) 2000,2002 Philip Kendall

   $Id: acconfig.h,v 1.21 2003/06/23 16:17:18 pak21 Exp $

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2 of the License, or
   (at your option) any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

   Author contact information:

   E-mail: pak21-fuse@srcf.ucam.org
   Postal address: 15 Crescent Road, Wokingham, Berks, RG40 2DB, England

*/

@TOP@

/* Defined if we're in debugging mode */
#undef DEBUG_MODE

/* Defined if we've got enough memory to compile z80_ops.c */
#undef HAVE_ENOUGH_MEMORY

/* Defined if we've got glib */
#undef HAVE_LIB_GLIB

/* Defined if we've got libxml2 */
#undef HAVE_LIB_XML2

/* Defined if Issue 2 emulation requested */
#undef ISSUE2

/* Defined if aalib UI in use */
#undef UI_AALIB

/* Defined if framebuffer UI in use */
#undef UI_FB

/* Defined if GGI UI in use */
#undef UI_GGI

/* Defined if GTK+ UI (either 1.2 or 2.x) is in use */
#undef UI_GTK

/* Defined if GTK+ 2.0 is in use */
#undef UI_GTK2

/* Defined if the SDL UI in use */
#undef UI_SDL

/* Defined if svgalib UI in use */
#undef UI_SVGA

/* Defined if Xlib UI in use */
#undef UI_X

/* Defined if we're going to be using the installed libpng */
#undef USE_LIBPNG

/* Defined if we're using a widget-based UI */
#undef USE_WIDGET
